#[repr(C)]pub enum Update {
DoNothing = 0,
RefreshDom = 1,
RefreshDomAllWindows = 2,
}Expand description
Specifies if the screen should be updated after the callback function has returned
Variants
DoNothing = 0
The screen does not need to redraw after the callback has been called
RefreshDom = 1
After the callback is called, the screen needs to redraw (layout() function being called again)
RefreshDomAllWindows = 2
The layout has to be re-calculated for all windows
Implementations