pub struct CoreCallbackDataVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl CoreCallbackDataVec
impl CoreCallbackDataVec
pub fn new() -> CoreCallbackDataVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [CoreCallbackData]) -> Self
pub fn from_vec(input: Vec<CoreCallbackData>) -> Self
pub fn iter(&self) -> Iter<'_, CoreCallbackData>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&CoreCallbackData>
pub fn get(&self, index: usize) -> Option<&CoreCallbackData>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionCoreCallbackDatawhere
CoreCallbackData: Clone,
pub fn c_get(&self, index: usize) -> OptionCoreCallbackDatawhere
CoreCallbackData: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[CoreCallbackData]
pub fn as_slice(&self) -> &[CoreCallbackData]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> CoreCallbackDataVecSlice
pub fn as_c_slice(&self) -> CoreCallbackDataVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> CoreCallbackDataVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> CoreCallbackDataVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const CoreCallbackData
pub fn as_ptr(&self) -> *const CoreCallbackData
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl CoreCallbackDataVec
impl CoreCallbackDataVec
pub fn from_copy_on_write( input: Cow<'static, [CoreCallbackData]>, ) -> CoreCallbackDataVec
Sourcepub fn from_item(item: CoreCallbackData) -> Self
pub fn from_item(item: CoreCallbackData) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const CoreCallbackData, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const CoreCallbackData, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<CoreCallbackData>
pub fn into_library_owned_vec(self) -> Vec<CoreCallbackData>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl CoreCallbackDataVec
impl CoreCallbackDataVec
pub fn as_mut_slice_extended<'a>(&mut self) -> &'a mut [CoreCallbackData]
pub fn as_mut_ptr(&mut self) -> *mut CoreCallbackData
pub fn sort_by<F: FnMut(&CoreCallbackData, &CoreCallbackData) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: CoreCallbackData)
pub fn insert(&mut self, index: usize, element: CoreCallbackData)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<CoreCallbackData>
pub fn iter_mut(&mut self) -> IterMut<'_, CoreCallbackData>
pub fn into_iter(self) -> IntoIter<CoreCallbackData>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl CoreCallbackDataVec
impl CoreCallbackDataVec
pub fn as_container<'a>(&'a self) -> NodeDataContainerRef<'a, CoreCallbackData>
pub fn as_container_mut<'a>( &'a mut self, ) -> NodeDataContainerRefMut<'a, CoreCallbackData>