pub struct DbValueVec { /* private fields */ }Implementations
Sourceimpl DbValueVec
impl DbValueVec
pub fn new() -> DbValueVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [DbValue]) -> Self
pub fn from_vec(input: Vec<DbValue>) -> Self
pub fn iter(&self) -> Iter<'_, DbValue>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&DbValue>
pub fn get(&self, index: usize) -> Option<&DbValue>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionDbValue
pub fn c_get(&self, index: usize) -> OptionDbValue
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[DbValue]
pub fn as_slice(&self) -> &[DbValue]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> DbValueVecSlice
pub fn as_c_slice(&self) -> DbValueVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> DbValueVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> DbValueVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl DbValueVec
impl DbValueVec
pub fn from_copy_on_write(input: Cow<'static, [DbValue]>) -> DbValueVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const DbValue, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const DbValue, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<DbValue>
pub fn into_library_owned_vec(self) -> Vec<DbValue>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated