#[repr(C, u8)]pub enum TabIndex {
Auto,
OverrideInParent(u32),
NoKeyboardFocus,
}Expand description
Determines the behavior of an element in sequential focus navigation
Variants
Auto
Automatic tab index, similar to simply setting focusable = "true" or tabindex = 0
(both have the effect of making the element focusable).
Sidenote: See https://www.w3.org/TR/html5/editing.html#sequential-focus-navigation-and-the-tabindex-attribute for interesting notes on tabindex and accessibility
OverrideInParent(u32)
Set the tab index in relation to its parent element. I.e. if you have a list of elements, the focusing order is restricted to the current parent.
When pressing tab repeatedly, the focusing order will be
determined by OverrideInParent elements taking precedence among global order.
NoKeyboardFocus
Elements can be focused in callbacks, but are not accessible via keyboard / tab navigation (-1).
Implementations