pub struct CssWithNodeIdVec { /* private fields */ }Implementations
Sourceimpl CssWithNodeIdVec
impl CssWithNodeIdVec
pub fn new() -> CssWithNodeIdVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [CssWithNodeId]) -> Self
pub fn from_vec(input: Vec<CssWithNodeId>) -> Self
pub fn iter(&self) -> Iter<'_, CssWithNodeId>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&CssWithNodeId>
pub fn get(&self, index: usize) -> Option<&CssWithNodeId>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionCssWithNodeIdwhere
CssWithNodeId: Clone,
pub fn c_get(&self, index: usize) -> OptionCssWithNodeIdwhere
CssWithNodeId: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[CssWithNodeId]
pub fn as_slice(&self) -> &[CssWithNodeId]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> CssWithNodeIdVecSlice
pub fn as_c_slice(&self) -> CssWithNodeIdVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> CssWithNodeIdVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> CssWithNodeIdVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const CssWithNodeId
pub fn as_ptr(&self) -> *const CssWithNodeId
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl CssWithNodeIdVec
impl CssWithNodeIdVec
pub fn from_copy_on_write( input: Cow<'static, [CssWithNodeId]>, ) -> CssWithNodeIdVec
Sourcepub fn from_item(item: CssWithNodeId) -> Self
pub fn from_item(item: CssWithNodeId) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const CssWithNodeId, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const CssWithNodeId, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<CssWithNodeId>
pub fn into_library_owned_vec(self) -> Vec<CssWithNodeId>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl CssWithNodeIdVec
impl CssWithNodeIdVec
pub fn as_mut_ptr(&mut self) -> *mut CssWithNodeId
pub fn sort_by<F: FnMut(&CssWithNodeId, &CssWithNodeId) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: CssWithNodeId)
pub fn insert(&mut self, index: usize, element: CssWithNodeId)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<CssWithNodeId>
pub fn iter_mut(&mut self) -> IterMut<'_, CssWithNodeId>
pub fn into_iter(self) -> IntoIter<CssWithNodeId>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)