pub struct NodeDataVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl NodeDataVec
impl NodeDataVec
pub fn new() -> NodeDataVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [NodeData]) -> Self
pub fn from_vec(input: Vec<NodeData>) -> Self
pub fn iter(&self) -> Iter<'_, NodeData>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&NodeData>
pub fn get(&self, index: usize) -> Option<&NodeData>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionNodeData
pub fn c_get(&self, index: usize) -> OptionNodeData
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[NodeData]
pub fn as_slice(&self) -> &[NodeData]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> NodeDataVecSlice
pub fn as_c_slice(&self) -> NodeDataVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> NodeDataVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> NodeDataVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl NodeDataVec
impl NodeDataVec
pub fn from_copy_on_write(input: Cow<'static, [NodeData]>) -> NodeDataVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const NodeData, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const NodeData, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<NodeData>
pub fn into_library_owned_vec(self) -> Vec<NodeData>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl NodeDataVec
impl NodeDataVec
pub fn as_mut_slice_extended<'a>(&mut self) -> &'a mut [NodeData]
pub fn as_mut_ptr(&mut self) -> *mut NodeData
pub fn sort_by<F: FnMut(&NodeData, &NodeData) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: NodeData)
pub fn insert(&mut self, index: usize, element: NodeData)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<NodeData>
pub fn iter_mut(&mut self) -> IterMut<'_, NodeData>
pub fn into_iter(self) -> IntoIter<NodeData>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl NodeDataVec
impl NodeDataVec
pub fn as_container<'a>(&'a self) -> NodeDataContainerRef<'a, NodeData>
pub fn as_container_mut<'a>( &'a mut self, ) -> NodeDataContainerRefMut<'a, NodeData>