DragContext

Struct DragContext 

pub struct DragContext {
    pub drag_type: ActiveDragType,
    pub session_id: u64,
    pub cancelled: bool,
}
The unified drag context.

This struct wraps ActiveDragType and provides common metadata that applies to all drag operations.

Fields

drag_type: ActiveDragType

The specific type of drag operation

session_id: u64

Session ID from gesture detection (links back to GestureManager)

cancelled: bool

Whether the drag has been cancelled (e.g., Escape pressed)

Implementations

Source

impl DragContext

pub fn new(drag_type: ActiveDragType, session_id: u64) -> Self

Create a new drag context

pub fn text_selection( dom_id: DomId, anchor_ifc_node: NodeId, start_mouse_position: LogicalPosition, session_id: u64, ) -> Self

Create a text selection drag

pub fn scrollbar_thumb( scroll_container_node: NodeId, axis: ScrollbarAxis, start_mouse_position: LogicalPosition, start_scroll_offset: f32, track_length_px: f32, content_length_px: f32, viewport_length_px: f32, session_id: u64, ) -> Self

Create a scrollbar thumb drag

pub fn node_drag( dom_id: DomId, node_id: NodeId, start_position: LogicalPosition, drag_data: DragData, session_id: u64, ) -> Self

Create a node drag

pub fn window_move( start_position: LogicalPosition, initial_window_position: WindowPosition, session_id: u64, ) -> Self

Create a window move drag

pub fn file_drop( files: Vec<AzString>, position: LogicalPosition, session_id: u64, ) -> Self

Create a file drop drag

pub fn update_position(&mut self, position: LogicalPosition)

Update the current mouse position for all drag types

pub fn current_position(&self) -> LogicalPosition

Get the current mouse position

pub fn start_position(&self) -> LogicalPosition

Get the start position

pub fn is_text_selection(&self) -> bool

Check if this is a text selection drag

pub fn is_scrollbar_thumb(&self) -> bool

Check if this is a scrollbar thumb drag

pub fn is_node_drag(&self) -> bool

Check if this is a node drag

pub fn is_window_move(&self) -> bool

Check if this is a window move drag

pub fn is_file_drop(&self) -> bool

Check if this is a file drop

pub fn as_text_selection(&self) -> Option<&TextSelectionDrag>

Get as text selection drag (if applicable)

pub fn as_text_selection_mut(&mut self) -> Option<&mut TextSelectionDrag>

Get as mutable text selection drag (if applicable)

pub fn as_scrollbar_thumb(&self) -> Option<&ScrollbarThumbDrag>

Get as scrollbar thumb drag (if applicable)

pub fn as_scrollbar_thumb_mut(&mut self) -> Option<&mut ScrollbarThumbDrag>

Get as mutable scrollbar thumb drag (if applicable)

pub fn as_node_drag(&self) -> Option<&NodeDrag>

Get as node drag (if applicable)

pub fn as_node_drag_mut(&mut self) -> Option<&mut NodeDrag>

Get as mutable node drag (if applicable)

pub fn as_window_move(&self) -> Option<&WindowMoveDrag>

Get as window move drag (if applicable)

pub fn as_file_drop(&self) -> Option<&FileDropDrag>

Get as file drop (if applicable)

pub fn as_file_drop_mut(&mut self) -> Option<&mut FileDropDrag>

Get as mutable file drop (if applicable)

pub fn calculate_scrollbar_scroll_offset(&self) -> Option<f32>

Calculate scroll delta for scrollbar thumb drag

Returns the new scroll offset based on current mouse position.

pub fn remap_node_ids( &mut self, dom_id: DomId, node_id_map: &BTreeMap<NodeId, NodeId>, ) -> bool

Remap NodeIds stored in this drag context after DOM reconciliation.

When the DOM is regenerated during an active drag, NodeIds can change. This updates all stored NodeIds using the old→new mapping. Returns false if a critical NodeId was removed (drag should be cancelled).