#[repr(C)]pub struct DragDelta {
pub dx: f32,
pub dy: f32,
}Expand description
Drag offset from the cursor position at drag start (logical pixels).
dx/dy are the delta from drag start to current position.
Fields
dx: f32dy: f32Implementations