#[repr(C)]pub struct PhysicalPosition<T> {
pub x: T,
pub y: T,
}Expand description
A 2D position in physical (pixel) coordinates.
Fields
x: Ty: TImplementations
Sourceimpl<T> PhysicalPosition<T>
impl<T> PhysicalPosition<T>
Sourceimpl PhysicalPosition<i32>
impl PhysicalPosition<i32>
pub const fn zero() -> Self
Sourcepub fn to_logical(self, hidpi_factor: f32) -> LogicalPosition
pub fn to_logical(self, hidpi_factor: f32) -> LogicalPosition
Converts to logical coordinates by dividing by the DPI factor.
Sourceimpl PhysicalPosition<f64>
impl PhysicalPosition<f64>
pub const fn zero() -> Self
Sourcepub fn to_logical(self, hidpi_factor: f32) -> LogicalPosition
pub fn to_logical(self, hidpi_factor: f32) -> LogicalPosition
Converts to logical coordinates by dividing by the DPI factor.