#[repr(C)]pub struct GlVoidPtrMut {
pub ptr: *mut GLvoid,
}Expand description
Struct returned from the C API
Because of Python, every object has to be clone-able, so yes there may exist more than one mutable reference
Fields
ptr: *mut GLvoidTrait Implementations
Sourceimpl Clone for GlVoidPtrMut
impl Clone for GlVoidPtrMut