#[repr(C)]pub struct VertexAttribute {
pub va_name: AzString,
pub layout_location: OptionUsize,
pub attribute_type: VertexAttributeType,
pub item_count: usize,
}Fields
va_name: AzStringAttribute name of the vertex attribute in the vertex shader, i.e. "vAttrXY"
layout_location: OptionUsizeIf the vertex shader has a specific location, (like layout(location = 2) vAttrXY),
use this instead of the name to look up the uniform location.
attribute_type: VertexAttributeTypeType of items of this attribute (i.e. for a FloatVec2, would be
VertexAttributeType::Float)
item_count: usizeNumber of items of this attribute (i.e. for a FloatVec2, would be 2 (= 2 consecutive
f32 values))
Implementations
Sourceimpl VertexAttribute
impl VertexAttribute
pub fn get_stride(&self) -> usize