pub struct HitTest {
pub regular_hit_test_nodes: BTreeMap<NodeId, HitTestItem>,
pub scroll_hit_test_nodes: BTreeMap<NodeId, ScrollHitTestItem>,
pub scrollbar_hit_test_nodes: BTreeMap<ScrollbarHitId, ScrollbarHitTestItem>,
pub cursor_hit_test_nodes: BTreeMap<NodeId, CursorHitTestItem>,
}Expand description
Result of a hit test against a single DOM, containing all nodes hit by the cursor along with scroll, scrollbar, and cursor-type information.
Fields
regular_hit_test_nodes: BTreeMap<NodeId, HitTestItem>scroll_hit_test_nodes: BTreeMap<NodeId, ScrollHitTestItem>scrollbar_hit_test_nodes: BTreeMap<ScrollbarHitId, ScrollbarHitTestItem>Hit test results for scrollbar components.
cursor_hit_test_nodes: BTreeMap<NodeId, CursorHitTestItem>Hit test results for cursor areas (text runs with cursor property). Maps NodeId to (CursorType, hit_depth) - the cursor type and z-depth of the hit.
Implementations