pub struct OverflowingScrollNode {
pub parent_rect: LogicalRect,
pub child_rect: LogicalRect,
pub virtual_child_rect: LogicalRect,
pub parent_external_scroll_id: ExternalScrollId,
pub parent_dom_hash: DomNodeHash,
pub scroll_tag_id: ScrollTagId,
}Expand description
A node whose content overflows its parent, requiring scroll handling.
Fields
parent_rect: LogicalRectchild_rect: LogicalRectvirtual_child_rect: LogicalRectparent_external_scroll_id: ExternalScrollIdparent_dom_hash: DomNodeHashscroll_tag_id: ScrollTagIdTrait Implementations
Sourceimpl Clone for OverflowingScrollNode
impl Clone for OverflowingScrollNode
Sourcefn clone(&self) -> OverflowingScrollNode
fn clone(&self) -> OverflowingScrollNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OverflowingScrollNode
impl Debug for OverflowingScrollNode
Sourceimpl Default for OverflowingScrollNode
impl Default for OverflowingScrollNode
Sourceimpl PartialEq for OverflowingScrollNode
impl PartialEq for OverflowingScrollNode
Sourcefn eq(&self, other: &OverflowingScrollNode) -> bool
fn eq(&self, other: &OverflowingScrollNode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OverflowingScrollNode
impl PartialOrd for OverflowingScrollNode
impl Copy for OverflowingScrollNode
impl StructuralPartialEq for OverflowingScrollNode