pub struct ScrollStates(pub OrderedMap<ExternalScrollId, ScrollState>);Expand description
Map of active scroll states, keyed by their external scroll ID.
Tuple Fields
0: OrderedMap<ExternalScrollId, ScrollState>Implementations
Sourceimpl ScrollStates
impl ScrollStates
pub fn new() -> Self
pub fn get_scroll_position( &self, scroll_id: &ExternalScrollId, ) -> Option<LogicalPosition>
Sourcepub fn set_scroll_position(
&mut self,
node: &OverflowingScrollNode,
scroll_position: LogicalPosition,
)
pub fn set_scroll_position( &mut self, node: &OverflowingScrollNode, scroll_position: LogicalPosition, )
Set the scroll amount - does not update the entry.used_this_frame,
since that is only relevant when we are actually querying the renderer.
Sourcepub fn scroll_node(
&mut self,
node: &OverflowingScrollNode,
scroll_by_x: f32,
scroll_by_y: f32,
)
pub fn scroll_node( &mut self, node: &OverflowingScrollNode, scroll_by_x: f32, scroll_by_y: f32, )
Updating (add to) the existing scroll amount does not update the
entry.used_this_frame, since that is only relevant when we are
actually querying the renderer.