pub struct NodeHierarchyRef<'a> {
pub internal: &'a [Node],
}Expand description
The hierarchy of nodes is stored separately from the actual node content in order to save on memory, since the hierarchy can be re-used across several DOM trees even if the content changes.
Fields
internal: &'a [Node]Implementations
Sourceimpl<'a> NodeHierarchyRef<'a>
impl<'a> NodeHierarchyRef<'a>
pub fn from_slice(data: &'a [Node]) -> NodeHierarchyRef<'a>
pub fn len(&self) -> usize
pub fn get(&self, id: NodeId) -> Option<&Node>
pub fn linear_iter(&self) -> LinearIterator ⓘ
Sourcepub fn get_parents_sorted_by_depth(&self) -> NodeDepths
pub fn get_parents_sorted_by_depth(&self) -> NodeDepths
Returns the (depth, NodeId) of all parent nodes (i.e. nodes that have a
first_child), in depth sorted order, (i.e. NodeId(0) with a depth of 0) is
the first element.
Runtime: O(n) max