#[repr(C)]pub enum MenuPopupPosition {
BottomLeftOfCursor = 0,
BottomRightOfCursor = 1,
TopLeftOfCursor = 2,
TopRightOfCursor = 3,
BottomOfHitRect = 4,
LeftOfHitRect = 5,
TopOfHitRect = 6,
RightOfHitRect = 7,
AutoCursor = 8,
AutoHitRect = 9,
}Expand description
Specifies where a popup menu should appear relative to the cursor or clicked element.
This positioning information is ignored for application-level menus (menu bars) and only applies to context menus and dropdowns.
Variants
BottomLeftOfCursor = 0
Position menu below and to the left of the cursor
BottomRightOfCursor = 1
Position menu below and to the right of the cursor
TopLeftOfCursor = 2
Position menu above and to the left of the cursor
TopRightOfCursor = 3
Position menu above and to the right of the cursor
BottomOfHitRect = 4
Position menu below the rectangle that was clicked
LeftOfHitRect = 5
Position menu to the left of the rectangle that was clicked
TopOfHitRect = 6
Position menu above the rectangle that was clicked
RightOfHitRect = 7
Position menu to the right of the rectangle that was clicked
AutoCursor = 8
Automatically calculate position based on available screen space near cursor
AutoHitRect = 9
Automatically calculate position based on available screen space near clicked rect