pub struct MenuItemVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl MenuItemVec
impl MenuItemVec
pub fn new() -> MenuItemVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [MenuItem]) -> Self
pub fn from_vec(input: Vec<MenuItem>) -> Self
pub fn iter(&self) -> Iter<'_, MenuItem>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&MenuItem>
pub fn get(&self, index: usize) -> Option<&MenuItem>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionMenuItem
pub fn c_get(&self, index: usize) -> OptionMenuItem
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[MenuItem]
pub fn as_slice(&self) -> &[MenuItem]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> MenuItemVecSlice
pub fn as_c_slice(&self) -> MenuItemVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> MenuItemVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> MenuItemVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl MenuItemVec
impl MenuItemVec
pub fn from_copy_on_write(input: Cow<'static, [MenuItem]>) -> MenuItemVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const MenuItem, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const MenuItem, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<MenuItem>
pub fn into_library_owned_vec(self) -> Vec<MenuItem>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated