#[repr(C)]pub struct ExternalImageData {
pub id: ExternalImageId,
pub channel_index: u8,
pub image_type: ExternalImageType,
}Expand description
Descriptor for external image resources. See ImageData.
Fields
id: ExternalImageIdThe identifier of this external image, provided by the embedding.
channel_index: u8For multi-plane images (i.e. YUV), indicates the plane of the original image that this struct represents. 0 for single-plane images.
image_type: ExternalImageTypeStorage format identifier.