#[repr(C)]pub struct ImageDescriptor {
pub format: RawImageFormat,
pub width: usize,
pub height: usize,
pub stride: OptionI32,
pub offset: i32,
pub flags: ImageDescriptorFlags,
}Expand description
Metadata (but not storage) describing an image In WebRender.
Fields
format: RawImageFormatFormat of the image data.
width: usizeWidth and height of the image data, in pixels.
height: usizestride: OptionI32The number of bytes from the start of one row to the next. If non-None,
compute_stride will return this value, otherwise it returns
width * bpp. Different source of images have different alignment
constraints for rows, so the stride isn’t always equal to width * bpp.
offset: i32Offset in bytes of the first pixel of this image in its backing buffer.
This is used for tiling, wherein WebRender extracts chunks of input images
in order to cache, manipulate, and render them individually. This offset
tells the texture upload machinery where to find the bytes to upload for
this tile. Non-tiled images generally set this to zero.
flags: ImageDescriptorFlagsVarious bool flags related to this descriptor.