pub struct NamedFontVec { /* private fields */ }Implementations
Sourceimpl NamedFontVec
impl NamedFontVec
pub const fn new() -> NamedFontVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [NamedFont]) -> Self
pub const fn from_vec(input: Vec<NamedFont>) -> Self
pub fn iter(&self) -> Iter<'_, NamedFont>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&NamedFont>
pub fn get(&self, index: usize) -> Option<&NamedFont>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionNamedFont
pub fn c_get(&self, index: usize) -> OptionNamedFont
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[NamedFont]
pub fn as_slice(&self) -> &[NamedFont]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub const fn as_c_slice(&self) -> NamedFontVecSlice
pub const fn as_c_slice(&self) -> NamedFontVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> NamedFontVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> NamedFontVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl NamedFontVec
impl NamedFontVec
pub const fn as_mut_ptr(&mut self) -> *mut NamedFont
pub fn sort_by<F: FnMut(&NamedFont, &NamedFont) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: NamedFont)
pub fn insert(&mut self, index: usize, element: NamedFont)
pub fn remove(&mut self, index: usize)
pub const fn pop(&mut self) -> Option<NamedFont>
pub fn iter_mut(&mut self) -> IterMut<'_, NamedFont>
pub fn into_iter(self) -> IntoIter<NamedFont>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl NamedFontVec
impl NamedFontVec
pub fn from_copy_on_write(input: Cow<'static, [NamedFont]>) -> NamedFontVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const NamedFont, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const NamedFont, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<NamedFont>
pub fn into_library_owned_vec(self) -> Vec<NamedFont>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated