pub struct DocumentTextEditVec { /* private fields */ }Implementations
Sourceimpl DocumentTextEditVec
impl DocumentTextEditVec
pub const fn new() -> DocumentTextEditVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [DocumentTextEdit]) -> Self
pub const fn from_vec(input: Vec<DocumentTextEdit>) -> Self
pub fn iter(&self) -> Iter<'_, DocumentTextEdit> ⓘ
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&DocumentTextEdit>
pub fn get(&self, index: usize) -> Option<&DocumentTextEdit>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionDocumentTextEditwhere
DocumentTextEdit: Clone,
pub fn c_get(&self, index: usize) -> OptionDocumentTextEditwhere
DocumentTextEdit: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[DocumentTextEdit]
pub fn as_slice(&self) -> &[DocumentTextEdit]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub const fn as_c_slice(&self) -> DocumentTextEditVecSlice
pub const fn as_c_slice(&self) -> DocumentTextEditVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> DocumentTextEditVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> DocumentTextEditVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub const fn as_ptr(&self) -> *const DocumentTextEdit
pub const fn as_ptr(&self) -> *const DocumentTextEdit
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl DocumentTextEditVec
impl DocumentTextEditVec
pub fn from_copy_on_write( input: Cow<'static, [DocumentTextEdit]>, ) -> DocumentTextEditVec
Sourcepub fn from_item(item: DocumentTextEdit) -> Self
pub fn from_item(item: DocumentTextEdit) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const DocumentTextEdit, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const DocumentTextEdit, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<DocumentTextEdit>
pub fn into_library_owned_vec(self) -> Vec<DocumentTextEdit>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated