#[repr(C)]pub struct TextCursor {
pub cluster_id: GraphemeClusterId,
pub affinity: CursorAffinity,
}Expand description
Represents a precise cursor location in the logical text.
Fields
cluster_id: GraphemeClusterIdThe grapheme cluster the cursor is associated with.
affinity: CursorAffinityThe edge of the cluster the cursor is on.