#[repr(C)]pub struct ContentInset {
pub left: f32,
pub top: f32,
}Expand description
The left/top inset from a node’s BORDER box to its CONTENT box:
padding-left + border-left-width and padding-top + border-top-width.
This is the E term in the module docs. It is the difference between the
box layout positions the node (border box, calculated_positions) and the
box inline text is laid out in (content box) — which is exactly the term
that used to be silently missing on one of the two hit-test hosts.
Fields
left: f32padding-left + border-left-width
top: f32padding-top + border-top-width
Implementations