pub struct ParentWithNodeDepthVec { /* private fields */ }Implementations
Sourceimpl ParentWithNodeDepthVec
impl ParentWithNodeDepthVec
pub fn new() -> ParentWithNodeDepthVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [ParentWithNodeDepth]) -> Self
pub fn from_vec(input: Vec<ParentWithNodeDepth>) -> Self
pub fn iter(&self) -> Iter<'_, ParentWithNodeDepth>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&ParentWithNodeDepth>
pub fn get(&self, index: usize) -> Option<&ParentWithNodeDepth>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionParentWithNodeDepthwhere
ParentWithNodeDepth: Clone,
pub fn c_get(&self, index: usize) -> OptionParentWithNodeDepthwhere
ParentWithNodeDepth: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[ParentWithNodeDepth]
pub fn as_slice(&self) -> &[ParentWithNodeDepth]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> ParentWithNodeDepthVecSlice
pub fn as_c_slice(&self) -> ParentWithNodeDepthVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> ParentWithNodeDepthVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> ParentWithNodeDepthVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const ParentWithNodeDepth
pub fn as_ptr(&self) -> *const ParentWithNodeDepth
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl ParentWithNodeDepthVec
impl ParentWithNodeDepthVec
pub fn as_mut_ptr(&mut self) -> *mut ParentWithNodeDepth
pub fn sort_by<F: FnMut(&ParentWithNodeDepth, &ParentWithNodeDepth) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: ParentWithNodeDepth)
pub fn insert(&mut self, index: usize, element: ParentWithNodeDepth)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<ParentWithNodeDepth>
pub fn iter_mut(&mut self) -> IterMut<'_, ParentWithNodeDepth>
pub fn into_iter(self) -> IntoIter<ParentWithNodeDepth>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl ParentWithNodeDepthVec
impl ParentWithNodeDepthVec
pub fn from_copy_on_write( input: Cow<'static, [ParentWithNodeDepth]>, ) -> ParentWithNodeDepthVec
Sourcepub fn from_item(item: ParentWithNodeDepth) -> Self
pub fn from_item(item: ParentWithNodeDepth) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const ParentWithNodeDepth, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const ParentWithNodeDepth, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<ParentWithNodeDepth>
pub fn into_library_owned_vec(self) -> Vec<ParentWithNodeDepth>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated