pub struct StyledNodeVec { /* private fields */ }Implementations
Sourceimpl StyledNodeVec
impl StyledNodeVec
pub fn new() -> StyledNodeVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [StyledNode]) -> Self
pub fn from_vec(input: Vec<StyledNode>) -> Self
pub fn iter(&self) -> Iter<'_, StyledNode>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&StyledNode>
pub fn get(&self, index: usize) -> Option<&StyledNode>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionStyledNodewhere
StyledNode: Clone,
pub fn c_get(&self, index: usize) -> OptionStyledNodewhere
StyledNode: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[StyledNode]
pub fn as_slice(&self) -> &[StyledNode]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> StyledNodeVecSlice
pub fn as_c_slice(&self) -> StyledNodeVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> StyledNodeVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> StyledNodeVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const StyledNode
pub fn as_ptr(&self) -> *const StyledNode
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl StyledNodeVec
impl StyledNodeVec
pub fn as_mut_ptr(&mut self) -> *mut StyledNode
pub fn sort_by<F: FnMut(&StyledNode, &StyledNode) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: StyledNode)
pub fn insert(&mut self, index: usize, element: StyledNode)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<StyledNode>
pub fn iter_mut(&mut self) -> IterMut<'_, StyledNode>
pub fn into_iter(self) -> IntoIter<StyledNode>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl StyledNodeVec
impl StyledNodeVec
pub fn from_copy_on_write(input: Cow<'static, [StyledNode]>) -> StyledNodeVec
Sourcepub fn from_item(item: StyledNode) -> Self
pub fn from_item(item: StyledNode) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const StyledNode, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const StyledNode, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<StyledNode>
pub fn into_library_owned_vec(self) -> Vec<StyledNode>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl StyledNodeVec
impl StyledNodeVec
Sourcepub fn as_container<'a>(&'a self) -> NodeDataContainerRef<'a, StyledNode>
pub fn as_container<'a>(&'a self) -> NodeDataContainerRef<'a, StyledNode>
Returns an immutable container reference for indexed access.
Sourcepub fn as_container_mut<'a>(
&'a mut self,
) -> NodeDataContainerRefMut<'a, StyledNode>
pub fn as_container_mut<'a>( &'a mut self, ) -> NodeDataContainerRefMut<'a, StyledNode>
Returns a mutable container reference for indexed access.