#[repr(C, u8)]pub enum SvgPathElement {
Line(SvgLine),
QuadraticCurve(SvgQuadraticCurve),
CubicCurve(SvgCubicCurve),
}Variants
Implementations
Sourceimpl SvgPathElement
impl SvgPathElement
Sourcepub const fn quadratic_curve(qc: SvgQuadraticCurve) -> Self
pub const fn quadratic_curve(qc: SvgQuadraticCurve) -> Self
Creates a quadratic curve path element from a SvgQuadraticCurve
Sourcepub const fn cubic_curve(cc: SvgCubicCurve) -> Self
pub const fn cubic_curve(cc: SvgCubicCurve) -> Self
Creates a cubic curve path element from a SvgCubicCurve
Sourcepub fn get_bounds(&self) -> SvgRect
pub fn get_bounds(&self) -> SvgRect
Returns the axis-aligned bounding rectangle of this path element.
Sourcepub fn get_length(&self) -> f64
pub fn get_length(&self) -> f64
Returns the arc length of this path element.
Sourcepub fn get_t_at_offset(&self, offset: f64) -> f64
pub fn get_t_at_offset(&self, offset: f64) -> f64
Returns the parametric t value at the given arc-length offset.
Sourcepub fn get_tangent_vector_at_t(&self, t: f64) -> SvgVector
pub fn get_tangent_vector_at_t(&self, t: f64) -> SvgVector
Returns the normalized tangent vector at parametric position t.
Sourcepub fn get_x_at_t(&self, t: f64) -> f64
pub fn get_x_at_t(&self, t: f64) -> f64
Returns the X coordinate at parametric position t.
Sourcepub fn get_y_at_t(&self, t: f64) -> f64
pub fn get_y_at_t(&self, t: f64) -> f64
Returns the Y coordinate at parametric position t.