pub struct SvgPathElementVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl SvgPathElementVec
impl SvgPathElementVec
pub fn new() -> SvgPathElementVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [SvgPathElement]) -> Self
pub fn from_vec(input: Vec<SvgPathElement>) -> Self
pub fn iter(&self) -> Iter<'_, SvgPathElement>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&SvgPathElement>
pub fn get(&self, index: usize) -> Option<&SvgPathElement>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionSvgPathElementwhere
SvgPathElement: Clone,
pub fn c_get(&self, index: usize) -> OptionSvgPathElementwhere
SvgPathElement: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[SvgPathElement]
pub fn as_slice(&self) -> &[SvgPathElement]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> SvgPathElementVecSlice
pub fn as_c_slice(&self) -> SvgPathElementVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> SvgPathElementVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> SvgPathElementVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const SvgPathElement
pub fn as_ptr(&self) -> *const SvgPathElement
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl SvgPathElementVec
impl SvgPathElementVec
pub fn from_copy_on_write( input: Cow<'static, [SvgPathElement]>, ) -> SvgPathElementVec
Sourcepub fn from_item(item: SvgPathElement) -> Self
pub fn from_item(item: SvgPathElement) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const SvgPathElement, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const SvgPathElement, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<SvgPathElement>
pub fn into_library_owned_vec(self) -> Vec<SvgPathElement>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated