#[repr(C)]pub struct ThreadReceiver {
pub ptr: Box<Arc<Mutex<ThreadReceiverInner>>>,
pub run_destructor: bool,
pub ctx: OptionRefAny,
}Expand description
Channel endpoint for receiving messages from the main thread in a background thread.
Thread-safe wrapper around the receiver end of a message channel.
Fields
ptr: Box<Arc<Mutex<ThreadReceiverInner>>>run_destructor: boolctx: OptionRefAnyFor FFI: stores the foreign callable (e.g., PyFunction)
Implementations
Sourceimpl ThreadReceiver
impl ThreadReceiver
Sourcepub fn new(t: ThreadReceiverInner) -> Self
pub fn new(t: ThreadReceiverInner) -> Self
Creates a new receiver wrapping the inner channel.
Sourcepub fn get_ctx(&self) -> OptionRefAny
pub fn get_ctx(&self) -> OptionRefAny
Get the FFI context (e.g., Python callable)
Sourcepub fn recv(&mut self) -> OptionThreadSendMsg
pub fn recv(&mut self) -> OptionThreadSendMsg
Receives a message from the main thread, if available.