pub struct TimerIdVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl TimerIdVec
impl TimerIdVec
pub fn new() -> TimerIdVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [TimerId]) -> Self
pub fn from_vec(input: Vec<TimerId>) -> Self
pub fn iter(&self) -> Iter<'_, TimerId>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&TimerId>
pub fn get(&self, index: usize) -> Option<&TimerId>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionTimerId
pub fn c_get(&self, index: usize) -> OptionTimerId
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[TimerId]
pub fn as_slice(&self) -> &[TimerId]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> TimerIdVecSlice
pub fn as_c_slice(&self) -> TimerIdVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> TimerIdVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> TimerIdVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl TimerIdVec
impl TimerIdVec
pub fn from_copy_on_write(input: Cow<'static, [TimerId]>) -> TimerIdVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const TimerId, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const TimerId, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<TimerId>
pub fn into_library_owned_vec(self) -> Vec<TimerId>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated