pub struct IconKey { /* private fields */ }Expand description
Key that is used for checking whether a window icon has changed -
this way azul doesn’t need to diff the actual bytes, just the icon key.
Use IconKey::new() to generate a new, unique key
Implementations