pub struct ScanCodeVec { /* private fields */ }Implementations
Sourceimpl ScanCodeVec
impl ScanCodeVec
pub fn new() -> ScanCodeVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [ScanCode]) -> Self
pub fn from_vec(input: Vec<ScanCode>) -> Self
pub fn iter(&self) -> Iter<'_, ScanCode>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&ScanCode>
pub fn get(&self, index: usize) -> Option<&ScanCode>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionU32
pub fn c_get(&self, index: usize) -> OptionU32
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[ScanCode] ⓘ
pub fn as_slice(&self) -> &[ScanCode] ⓘ
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> ScanCodeVecSlice
pub fn as_c_slice(&self) -> ScanCodeVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> ScanCodeVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> ScanCodeVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl ScanCodeVec
impl ScanCodeVec
pub fn from_copy_on_write(input: Cow<'static, [ScanCode]>) -> ScanCodeVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const ScanCode, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const ScanCode, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<ScanCode> ⓘ
pub fn into_library_owned_vec(self) -> Vec<ScanCode> ⓘ
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl ScanCodeVec
impl ScanCodeVec
pub fn as_mut_ptr(&mut self) -> *mut ScanCode
pub fn sort_by<F: FnMut(&ScanCode, &ScanCode) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: ScanCode)
pub fn insert(&mut self, index: usize, element: ScanCode)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<ScanCode>
pub fn iter_mut(&mut self) -> IterMut<'_, ScanCode>
pub fn into_iter(self) -> IntoIter<ScanCode>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl ScanCodeVec
impl ScanCodeVec
pub fn insert_hm_item(&mut self, item: ScanCode)
pub fn remove_hm_item(&mut self, remove_key: &ScanCode)
pub fn contains_hm_item(&self, searched: &ScanCode) -> bool