ScrollResult

Struct ScrollResult 

#[repr(C)]
pub struct ScrollResult { pub scrolled_nodes: usize, pub remaining_delta: LogicalPosition, pub hit_scrollbar: bool, }
Result of dispatching a scroll delta into the system scroll-handling pipeline.

Returned by process_system_scroll. Higher layers can use the ScrollResult::remaining_delta to forward un-consumed scroll to a parent container, and ScrollResult::hit_scrollbar to distinguish scrollbar-drag scrolling from wheel-on-content scrolling for hit-testing purposes.

Fields

scrolled_nodes: usize

Number of scrollable nodes whose offset was updated by this dispatch.

remaining_delta: LogicalPosition

Delta that could not be consumed (overscroll). May be forwarded to a parent.

hit_scrollbar: bool

true if the dispatch hit a native scrollbar (drag), false for wheel/touch.