#[repr(C)]pub struct WebHandle {
pub id: u32,
}Fields
id: u32An ID value inserted into the data attributes of the canvas element as ‘raw-handle’
When accessing from JS, the attribute will automatically be called rawHandle. Each canvas created by the windowing system should be assigned their own unique ID. 0 should be reserved for invalid / null IDs.