#[repr(C, u8)]pub enum ComponentError {
UselessFunctionArgument(UselessFunctionArgumentError),
UnknownComponent(AzString),
}Variants
UselessFunctionArgument(UselessFunctionArgumentError)
While instantiating a component, a function argument was encountered that the component won’t use or react to.
UnknownComponent(AzString)
A certain node type can’t be rendered, because the renderer for this node is not available isn’t available
UnknownComponent(component_name)