ComponentParseError

Enum ComponentParseError 

#[repr(C, u8)]
pub enum ComponentParseError { NotAComponent, UnnamedComponent, MissingName(usize), MissingType(MissingTypeError), WhiteSpaceInComponentName(WhiteSpaceInComponentNameError), WhiteSpaceInComponentType(WhiteSpaceInComponentTypeError), CssError(CssParseErrorOwned), }

Variants



NotAComponent

Given XmlNode is not a <component /> node.



UnnamedComponent

A <component> node does not have a name attribute.



MissingName(usize)

Argument at position usize is either empty or has no name



MissingType(MissingTypeError)

Argument at position usize with the name String doesn’t have a : type



WhiteSpaceInComponentName(WhiteSpaceInComponentNameError)

Component name may not contain a whitespace (probably missing a : between the name and the type)



WhiteSpaceInComponentType(WhiteSpaceInComponentTypeError)

Component type may not contain a whitespace (probably missing a , between the type and the next name)



CssError(CssParseErrorOwned)

Error parsing the