#[repr(C)]pub struct ComponentArgument {
pub name: AzString,
pub arg_type: AzString,
}Expand description
FFI-safe replacement for (ComponentArgumentName, ComponentArgumentType) tuple.
Fields
name: AzStringarg_type: AzStringTrait Implementations
Sourceimpl Clone for ComponentArgument
impl Clone for ComponentArgument
Sourcefn clone(&self) -> ComponentArgument
fn clone(&self) -> ComponentArgument
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComponentArgument
impl Debug for ComponentArgument
Sourceimpl Default for ComponentArgument
impl Default for ComponentArgument
Sourcefn default() -> ComponentArgument
fn default() -> ComponentArgument
Returns the “default value” for a type. Read more
Sourceimpl Extend<ComponentArgument> for ComponentArgumentVec
impl Extend<ComponentArgument> for ComponentArgumentVec
Sourcefn extend<T: IntoIterator<Item = ComponentArgument>>(&mut self, iter: T)
fn extend<T: IntoIterator<Item = ComponentArgument>>(&mut self, iter: T)
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl FromIterator<ComponentArgument> for ComponentArgumentVec
impl FromIterator<ComponentArgument> for ComponentArgumentVec
Sourcefn from_iter<T>(iter: T) -> Selfwhere
T: IntoIterator<Item = ComponentArgument>,
fn from_iter<T>(iter: T) -> Selfwhere
T: IntoIterator<Item = ComponentArgument>,
Creates a value from an iterator. Read more
Sourceimpl Hash for ComponentArgument
impl Hash for ComponentArgument
Sourceimpl Ord for ComponentArgument
impl Ord for ComponentArgument
Sourcefn cmp(&self, other: &ComponentArgument) -> Ordering
fn cmp(&self, other: &ComponentArgument) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ComponentArgument
impl PartialEq for ComponentArgument
Sourcefn eq(&self, other: &ComponentArgument) -> bool
fn eq(&self, other: &ComponentArgument) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ComponentArgument
impl PartialOrd for ComponentArgument
impl Eq for ComponentArgument
impl StructuralPartialEq for ComponentArgument