pub struct ComponentArguments {
pub args: ComponentArgumentVec,
pub accepts_text: bool,
}Expand description
Holds the list of arguments and whether the component accepts text content. Used by the compile pipeline to generate Rust function signatures.
Fields
args: ComponentArgumentVecaccepts_text: boolTrait Implementations
Sourceimpl Clone for ComponentArguments
impl Clone for ComponentArguments
Sourcefn clone(&self) -> ComponentArguments
fn clone(&self) -> ComponentArguments
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComponentArguments
impl Debug for ComponentArguments
Sourceimpl Default for ComponentArguments
impl Default for ComponentArguments
Sourcefn default() -> ComponentArguments
fn default() -> ComponentArguments
Returns the “default value” for a type. Read more
Sourceimpl Hash for ComponentArguments
impl Hash for ComponentArguments
Sourceimpl Ord for ComponentArguments
impl Ord for ComponentArguments
Sourcefn cmp(&self, other: &ComponentArguments) -> Ordering
fn cmp(&self, other: &ComponentArguments) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ComponentArguments
impl PartialEq for ComponentArguments
Sourcefn eq(&self, other: &ComponentArguments) -> bool
fn eq(&self, other: &ComponentArguments) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ComponentArguments
impl PartialOrd for ComponentArguments
impl Eq for ComponentArguments
impl StructuralPartialEq for ComponentArguments