#[repr(C)]pub struct XmlAttributeMap {
pub inner: StringPairVec,
}Expand description
Attributes of an XML node, such as ["color" => "blue"] in <button color="blue" />.
Fields
inner: StringPairVecMethods from Deref<Target = StringPairVec>
pub fn iter(&self) -> Iter<'_, AzStringPair>
pub fn ptr_as_usize(&self) -> usize
pub fn len(&self) -> usize
pub fn capacity(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&AzStringPair>
pub fn get(&self, index: usize) -> Option<&AzStringPair>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionStringPairwhere
AzStringPair: Clone,
pub fn c_get(&self, index: usize) -> OptionStringPairwhere
AzStringPair: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[AzStringPair]
pub fn as_slice(&self) -> &[AzStringPair]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> StringPairVecSlice
pub fn as_c_slice(&self) -> StringPairVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> StringPairVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> StringPairVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const AzStringPair
pub fn as_ptr(&self) -> *const AzStringPair
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
pub fn as_mut_slice_extended<'a>(&mut self) -> &'a mut [AzStringPair]
pub fn as_mut_ptr(&mut self) -> *mut AzStringPair
pub fn sort_by<F: FnMut(&AzStringPair, &AzStringPair) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: AzStringPair)
pub fn insert(&mut self, index: usize, element: AzStringPair)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<AzStringPair>
pub fn iter_mut(&mut self) -> IterMut<'_, AzStringPair>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
pub fn get_key(&self, search_key: &str) -> Option<&AzString>
pub fn get_key_mut(&mut self, search_key: &str) -> Option<&mut AzStringPair>
pub fn insert_kv<I: Into<AzString>>(&mut self, key: I, value: I)