[−][src]Crate azul_core
Shared datatypes for azul-* crates
Modules
| app_resources | Functions to manage adding fonts + images, garbage collection |
| callbacks | Type definitions for various types of callbacks, as well as focus and scroll handling |
| diff | Algorithms to create git-like diffs between two doms in linear time |
| display_list | Layout and display list creation algorithm, z-index reordering of |
| dom |
|
| gl | Contains OpenGL helper functions (to compile / link shaders), |
| id_tree | Internal, arena-based storage for Dom nodes |
| macros | Useful macros for implementing Azul APIs without duplicating code |
| style | CSS cascading module DOM tree to CSS style tree cascading |
| task | Async (task, thread, timer) helper functions |
| traits | Main |
| ui_description |
|
| ui_solver | |
| ui_state | Contains functions to build the |
| window | |
| window_state |
Macros
| impl_callback | Implements |
| impl_display | Implement |
| impl_font_api | |
| impl_from | Implement the |
| impl_image_api | |
| impl_task_api | Implements functions for |
| impl_text_api | |
| impl_timer_api |
Type Definitions
| FastHashMap | |
| FastHashSet |