pub struct CssPropertyWithConditionsVec { /* private fields */ }Implementations
Sourceimpl CssPropertyWithConditionsVec
impl CssPropertyWithConditionsVec
pub const fn new() -> CssPropertyWithConditionsVec
pub fn with_capacity(cap: usize) -> CssPropertyWithConditionsVec
pub const fn from_const_slice( input: &'static [CssPropertyWithConditions], ) -> CssPropertyWithConditionsVec
pub const fn from_vec( input: Vec<CssPropertyWithConditions>, ) -> CssPropertyWithConditionsVec
pub fn iter(&self) -> Iter<'_, CssPropertyWithConditions>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&CssPropertyWithConditions>
pub fn get(&self, index: usize) -> Option<&CssPropertyWithConditions>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionCssPropertyWithConditionswhere
CssPropertyWithConditions: Clone,
pub fn c_get(&self, index: usize) -> OptionCssPropertyWithConditionswhere
CssPropertyWithConditions: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[CssPropertyWithConditions]
pub fn as_slice(&self) -> &[CssPropertyWithConditions]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub const fn as_c_slice(&self) -> CssPropertyWithConditionsVecSlice
pub const fn as_c_slice(&self) -> CssPropertyWithConditionsVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> CssPropertyWithConditionsVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> CssPropertyWithConditionsVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub const fn as_ptr(&self) -> *const CssPropertyWithConditions
pub const fn as_ptr(&self) -> *const CssPropertyWithConditions
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl CssPropertyWithConditionsVec
impl CssPropertyWithConditionsVec
pub fn from_copy_on_write( input: Cow<'static, [CssPropertyWithConditions]>, ) -> CssPropertyWithConditionsVec
Sourcepub fn from_item(
item: CssPropertyWithConditions,
) -> CssPropertyWithConditionsVec
pub fn from_item( item: CssPropertyWithConditions, ) -> CssPropertyWithConditionsVec
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(
ptr: *const CssPropertyWithConditions,
len: usize,
) -> CssPropertyWithConditionsVec
pub unsafe fn copy_from_ptr( ptr: *const CssPropertyWithConditions, len: usize, ) -> CssPropertyWithConditionsVec
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> CssPropertyWithConditionsVec
pub fn clone_self(&self) -> CssPropertyWithConditionsVec
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<CssPropertyWithConditions>
pub fn into_library_owned_vec(self) -> Vec<CssPropertyWithConditions>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl CssPropertyWithConditionsVec
impl CssPropertyWithConditionsVec
Sourcepub fn parse(style: &str) -> CssPropertyWithConditionsVec
pub fn parse(style: &str) -> CssPropertyWithConditionsVec
Parse CSS with support for selectors and nesting.
Supports:
- Simple properties:
color: red; - Pseudo-selectors:
:hover { background: blue; } - @-rules:
@os linux { font-size: 14px; } - Nesting:
@os linux { font-size: 14px; :hover { color: red; }}
Examples:
// Simple inline styles
CssPropertyWithConditionsVec::parse("color: red; font-size: 14px;")
// With hover state
CssPropertyWithConditionsVec::parse(":hover { background: blue; }")
// OS-specific with nested hover
CssPropertyWithConditionsVec::parse("@os linux { font-size: 14px; :hover { color: red; }}")Trait Implementations
Sourceimpl AsRef<[CssPropertyWithConditions]> for CssPropertyWithConditionsVec
impl AsRef<[CssPropertyWithConditions]> for CssPropertyWithConditionsVec
Sourcefn as_ref(&self) -> &[CssPropertyWithConditions]
fn as_ref(&self) -> &[CssPropertyWithConditions]
Sourceimpl Clone for CssPropertyWithConditionsVec
impl Clone for CssPropertyWithConditionsVec
Sourcefn clone(&self) -> CssPropertyWithConditionsVec
fn clone(&self) -> CssPropertyWithConditionsVec
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more