#[repr(C)]pub enum DropEffect {
None = 0,
Copy = 1,
Link = 2,
Move = 3,
}Expand description
Drop effect — the operation that will happen if the data is dropped
on the current target (HTML5 DataTransfer.dropEffect).
This is a strict subset of DragEffect: a drop target selects one of
these four outcomes, which must also be allowed by the source’s
effect_allowed.
Variants
None = 0
No drop allowed / the drop is rejected. Default.
Copy = 1
Drop will copy the data (source retains its copy).
Link = 2
Drop will create a link/shortcut to the data.
Move = 3
Drop will move the data (source should remove its copy).