pub struct InputInterpreterInfo<'a> {
pub events: &'a [SyntheticEvent],
pub hit_test: Option<&'a FullHitTest>,
pub keyboard_state: &'a KeyboardState,
pub mouse_state: &'a MouseState,
pub state: InputInterpreterState,
}Expand description
All context needed by the input interpreter to map events to system changes.
Passed to the interpreter callback. Contains references to the current events and window state. The interpreter reads this and returns system changes.
Fields
events: &'a [SyntheticEvent]hit_test: Option<&'a FullHitTest>keyboard_state: &'a KeyboardStatemouse_state: &'a MouseStatestate: InputInterpreterStateAuto Trait Implementations
impl<'a> Freeze for InputInterpreterInfo<'a>
impl<'a> RefUnwindSafe for InputInterpreterInfo<'a>
impl<'a> Send for InputInterpreterInfo<'a>
impl<'a> Sync for InputInterpreterInfo<'a>
impl<'a> Unpin for InputInterpreterInfo<'a>
impl<'a> UnsafeUnpin for InputInterpreterInfo<'a>
impl<'a> UnwindSafe for InputInterpreterInfo<'a>