pub struct ScrollHitTestItem {
pub point_in_viewport: LogicalPosition,
pub point_relative_to_item: LogicalPosition,
pub scroll_node: OverflowingScrollNode,
}Expand description
A hit-test result for a scrollable DOM node.
Fields
point_in_viewport: LogicalPositionThe hit point in the coordinate space of the “viewport” of the display item. The viewport is the scroll node formed by the root reference frame of the display item’s pipeline.
point_relative_to_item: LogicalPositionThe coordinates of the original hit test point relative to the origin of this item. This is useful for calculating things like text offsets in the client.
scroll_node: OverflowingScrollNodeIf this hit is a VirtualView node, stores the VirtualViews DomId + the origin of the VirtualView