pub struct JsonVec { /* private fields */ }Implementations
Sourceimpl JsonVec
impl JsonVec
pub fn new() -> JsonVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [Json]) -> Self
pub fn from_vec(input: Vec<Json>) -> Self
pub fn iter(&self) -> Iter<'_, Json>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&Json>
pub fn get(&self, index: usize) -> Option<&Json>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionJson
pub fn c_get(&self, index: usize) -> OptionJson
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[Json]
pub fn as_slice(&self) -> &[Json]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> JsonVecSlice
pub fn as_c_slice(&self) -> JsonVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> JsonVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> JsonVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl JsonVec
impl JsonVec
pub fn from_copy_on_write(input: Cow<'static, [Json]>) -> JsonVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const Json, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const Json, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<Json>
pub fn into_library_owned_vec(self) -> Vec<Json>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl JsonVec
impl JsonVec
pub fn as_mut_ptr(&mut self) -> *mut Json
pub fn sort_by<F: FnMut(&Json, &Json) -> Ordering>(&mut self, compare: F)
pub fn push(&mut self, value: Json)
pub fn insert(&mut self, index: usize, element: Json)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<Json>
pub fn iter_mut(&mut self) -> IterMut<'_, Json>
pub fn into_iter(self) -> IntoIter<Json>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)