#[repr(C)]pub struct MouseState {
pub mouse_cursor_type: OptionMouseCursorType,
pub cursor_position: CursorPosition,
pub is_cursor_locked: bool,
pub left_down: bool,
pub right_down: bool,
pub middle_down: bool,
}Expand description
Mouse position, cursor type, user scroll input, etc.
Fields
mouse_cursor_type: OptionMouseCursorTypeCurrent mouse cursor type, set to None if the cursor is hidden. (READWRITE)
cursor_position: CursorPositionWhere is the mouse cursor currently? Set to None if the window is not focused.
(READWRITE)
is_cursor_locked: boolIs the mouse cursor locked to the current window (important for applications like games)? (READWRITE)
left_down: boolIs the left mouse button down? (READONLY)
right_down: boolIs the right mouse button down? (READONLY)
middle_down: boolIs the middle mouse button down? (READONLY)
Implementations
Sourceimpl MouseState
impl MouseState
pub fn matches(&self, context: &ContextMenuMouseButton) -> bool
Sourceimpl MouseState
impl MouseState
Sourcepub fn mouse_down(&self) -> bool
pub fn mouse_down(&self) -> bool
Returns whether any mouse button (left, right or center) is currently held down
Snapshot the button-down flags as a MouseButtonState for drag tracking.